@@ -858,7 +858,10 @@ class BaiduPCS:
         hdrs["Referer"] = shared_url  # WARNING: Referer must be set to shared_url
 
         resp = self._request(Method.Post, url, headers=hdrs, params=params, data=data)
-        return resp.json()
+        info = resp.json()
+        if info.get("info") and info["info"][0]["errno"]:
+            info["errno"] = info["info"][0]["errno"]
+        return info
 
     @assert_ok
     def user_info(self):
