@@ -3,6 +3,8 @@ from pathlib import Path
 import os
 from os import PathLike
 
+from baidupcs_py.common.platform import IS_WIN
+
 
 def exists(localpath: PathLike) -> bool:
     localpath = Path(localpath)
@@ -27,8 +29,23 @@ def walk(localpath: PathLike) -> Iterator[str]:
 
 
 def join_path(source: PathLike, dest: PathLike) -> str:
-    if not isinstance(source, Path):
-        source = Path(source)
-    if not isinstance(dest, Path):
-        dest = Path(dest)
-    return (source / dest).resolve().as_posix()
+    """Join posix paths"""
+
+    _path = (Path(source) / dest).as_posix()
+    has_root = _path.startswith("/")
+    if not has_root:
+        _path = "/" + _path
+
+    path = Path(_path).resolve().as_posix()
+
+    if IS_WIN:
+        p = path.split(":", 1)[-1]
+        if not has_root:
+            return p[1:]
+        else:
+            return p
+    else:
+        if not has_root:
+            return path[1:]
+        else:
+            return path
